summaryrefslogtreecommitdiffhomepage
path: root/examples/web/models/models_obj_loading.c
diff options
context:
space:
mode:
Diffstat (limited to 'examples/web/models/models_obj_loading.c')
-rw-r--r--examples/web/models/models_obj_loading.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/examples/web/models/models_obj_loading.c b/examples/web/models/models_obj_loading.c
index c816372..f58a3ad 100644
--- a/examples/web/models/models_obj_loading.c
+++ b/examples/web/models/models_obj_loading.c
@@ -45,7 +45,7 @@ int main()
dwarf = LoadModel("resources/model/dwarf.obj"); // Load OBJ model
texture = LoadTexture("resources/model/dwarf_diffuse.png"); // Load model texture
- dwarf.material.texDiffuse = texture; // Set dwarf model diffuse texture
+ dwarf.material.maps[MAP_DIFFUSE].texture = texture; // Set map diffuse texture
#if defined(PLATFORM_WEB)
emscripten_set_main_loop(UpdateDrawFrame, 0, 1);